Class: Aws::FMS::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::FMS::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-fms/client.rb,
sig/client.rbs
Overview
An API client for FMS. To construct a client, you need to configure a :region and :credentials.
client = Aws::FMS::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateThirdPartyFirewallResponseSuccess, _BatchAssociateResourceResponseSuccess, _BatchDisassociateResourceResponseSuccess, _DisassociateThirdPartyFirewallResponseSuccess, _GetAdminAccountResponseSuccess, _GetAdminScopeResponseSuccess, _GetAppsListResponseSuccess, _GetComplianceDetailResponseSuccess, _GetNotificationChannelResponseSuccess, _GetPolicyResponseSuccess, _GetProtectionStatusResponseSuccess, _GetProtocolsListResponseSuccess, _GetResourceSetResponseSuccess, _GetThirdPartyFirewallAssociationStatusResponseSuccess, _GetViolationDetailsResponseSuccess, _ListAdminAccountsForOrganizationResponseSuccess, _ListAdminsManagingAccountResponseSuccess, _ListAppsListsResponseSuccess, _ListComplianceStatusResponseSuccess, _ListDiscoveredResourcesResponseSuccess, _ListMemberAccountsResponseSuccess, _ListPoliciesResponseSuccess, _ListProtocolsListsResponseSuccess, _ListResourceSetResourcesResponseSuccess, _ListResourceSetsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListThirdPartyFirewallFirewallPoliciesResponseSuccess, _PutAppsListResponseSuccess, _PutPolicyResponseSuccess, _PutProtocolsListResponseSuccess, _PutResourceSetResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_admin_account(params = {}) ⇒ Struct
Sets a Firewall Manager default administrator account.
-
#associate_third_party_firewall(params = {}) ⇒ Types::AssociateThirdPartyFirewallResponse
Sets the Firewall Manager policy administrator as a tenant administrator of a third-party firewall service.
-
#batch_associate_resource(params = {}) ⇒ Types::BatchAssociateResourceResponse
Associate resources to a Firewall Manager resource set.
-
#batch_disassociate_resource(params = {}) ⇒ Types::BatchDisassociateResourceResponse
Disassociates resources from a Firewall Manager resource set.
-
#delete_apps_list(params = {}) ⇒ Struct
Permanently deletes an Firewall Manager applications list.
-
#delete_notification_channel(params = {}) ⇒ Struct
Deletes an Firewall Manager association with the IAM role and the Amazon Simple Notification Service (SNS) topic that is used to record Firewall Manager SNS logs.
-
#delete_policy(params = {}) ⇒ Struct
Permanently deletes an Firewall Manager policy.
-
#delete_protocols_list(params = {}) ⇒ Struct
Permanently deletes an Firewall Manager protocols list.
-
#delete_resource_set(params = {}) ⇒ Struct
Deletes the specified ResourceSet.
-
#disassociate_admin_account(params = {}) ⇒ Struct
Disassociates an Firewall Manager administrator account.
-
#disassociate_third_party_firewall(params = {}) ⇒ Types::DisassociateThirdPartyFirewallResponse
Disassociates a Firewall Manager policy administrator from a third-party firewall tenant.
-
#get_admin_account(params = {}) ⇒ Types::GetAdminAccountResponse
Returns the Organizations account that is associated with Firewall Manager as the Firewall Manager default administrator.
-
#get_admin_scope(params = {}) ⇒ Types::GetAdminScopeResponse
Returns information about the specified account's administrative scope.
-
#get_apps_list(params = {}) ⇒ Types::GetAppsListResponse
Returns information about the specified Firewall Manager applications list.
-
#get_compliance_detail(params = {}) ⇒ Types::GetComplianceDetailResponse
Returns detailed compliance information about the specified member account.
-
#get_notification_channel(params = {}) ⇒ Types::GetNotificationChannelResponse
Information about the Amazon Simple Notification Service (SNS) topic that is used to record Firewall Manager SNS logs.
-
#get_policy(params = {}) ⇒ Types::GetPolicyResponse
Returns information about the specified Firewall Manager policy.
-
#get_protection_status(params = {}) ⇒ Types::GetProtectionStatusResponse
If you created a Shield Advanced policy, returns policy-level attack summary information in the event of a potential DDoS attack.
-
#get_protocols_list(params = {}) ⇒ Types::GetProtocolsListResponse
Returns information about the specified Firewall Manager protocols list.
-
#get_resource_set(params = {}) ⇒ Types::GetResourceSetResponse
Gets information about a specific resource set.
-
#get_third_party_firewall_association_status(params = {}) ⇒ Types::GetThirdPartyFirewallAssociationStatusResponse
The onboarding status of a Firewall Manager admin account to third-party firewall vendor tenant.
-
#get_violation_details(params = {}) ⇒ Types::GetViolationDetailsResponse
Retrieves violations for a resource based on the specified Firewall Manager policy and Amazon Web Services account.
-
#list_admin_accounts_for_organization(params = {}) ⇒ Types::ListAdminAccountsForOrganizationResponse
Returns a
AdminAccountsobject that lists the Firewall Manager administrators within the organization that are onboarded to Firewall Manager by AssociateAdminAccount. -
#list_admins_managing_account(params = {}) ⇒ Types::ListAdminsManagingAccountResponse
Lists the accounts that are managing the specified Organizations member account.
-
#list_apps_lists(params = {}) ⇒ Types::ListAppsListsResponse
Returns an array of
AppsListDataSummaryobjects. -
#list_compliance_status(params = {}) ⇒ Types::ListComplianceStatusResponse
Returns an array of
PolicyComplianceStatusobjects. -
#list_discovered_resources(params = {}) ⇒ Types::ListDiscoveredResourcesResponse
Returns an array of resources in the organization's accounts that are available to be associated with a resource set.
-
#list_member_accounts(params = {}) ⇒ Types::ListMemberAccountsResponse
Returns a
MemberAccountsobject that lists the member accounts in the administrator's Amazon Web Services organization. -
#list_policies(params = {}) ⇒ Types::ListPoliciesResponse
Returns an array of
PolicySummaryobjects. -
#list_protocols_lists(params = {}) ⇒ Types::ListProtocolsListsResponse
Returns an array of
ProtocolsListDataSummaryobjects. -
#list_resource_set_resources(params = {}) ⇒ Types::ListResourceSetResourcesResponse
Returns an array of resources that are currently associated to a resource set.
-
#list_resource_sets(params = {}) ⇒ Types::ListResourceSetsResponse
Returns an array of
ResourceSetSummaryobjects. -
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the list of tags for the specified Amazon Web Services resource.
-
#list_third_party_firewall_firewall_policies(params = {}) ⇒ Types::ListThirdPartyFirewallFirewallPoliciesResponse
Retrieves a list of all of the third-party firewall policies that are associated with the third-party firewall administrator's account.
-
#put_admin_account(params = {}) ⇒ Struct
Creates or updates an Firewall Manager administrator account.
-
#put_apps_list(params = {}) ⇒ Types::PutAppsListResponse
Creates an Firewall Manager applications list.
-
#put_notification_channel(params = {}) ⇒ Struct
Designates the IAM role and Amazon Simple Notification Service (SNS) topic that Firewall Manager uses to record SNS logs.
-
#put_policy(params = {}) ⇒ Types::PutPolicyResponse
Creates an Firewall Manager policy.
-
#put_protocols_list(params = {}) ⇒ Types::PutProtocolsListResponse
Creates an Firewall Manager protocols list.
-
#put_resource_set(params = {}) ⇒ Types::PutResourceSetResponse
Creates the resource set.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to an Amazon Web Services resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from an Amazon Web Services resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-fms/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3000 3001 3002 |
# File 'lib/aws-sdk-fms/client.rb', line 3000 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3003 3004 3005 |
# File 'lib/aws-sdk-fms/client.rb', line 3003 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_admin_account(params = {}) ⇒ Struct
Sets a Firewall Manager default administrator account. The Firewall Manager default administrator account can manage third-party firewalls and has full administrative scope that allows administration of all policy types, accounts, organizational units, and Regions. This account must be a member account of the organization in Organizations whose resources you want to protect.
For information about working with Firewall Manager administrator accounts, see Managing Firewall Manager administrators in the Firewall Manager Developer Guide.
83 |
# File 'sig/client.rbs', line 83
def associate_admin_account: (
|
#associate_third_party_firewall(params = {}) ⇒ Types::AssociateThirdPartyFirewallResponse
Sets the Firewall Manager policy administrator as a tenant administrator of a third-party firewall service. A tenant is an instance of the third-party firewall service that's associated with your Amazon Web Services customer account.
93 |
# File 'sig/client.rbs', line 93
def associate_third_party_firewall: (
|
#batch_associate_resource(params = {}) ⇒ Types::BatchAssociateResourceResponse
Associate resources to a Firewall Manager resource set.
104 |
# File 'sig/client.rbs', line 104
def batch_associate_resource: (
|
#batch_disassociate_resource(params = {}) ⇒ Types::BatchDisassociateResourceResponse
Disassociates resources from a Firewall Manager resource set.
116 |
# File 'sig/client.rbs', line 116
def batch_disassociate_resource: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 2987 2988 2989 |
# File 'lib/aws-sdk-fms/client.rb', line 2973 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::FMS') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-fms' context[:gem_version] = '1.111.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_apps_list(params = {}) ⇒ Struct
Permanently deletes an Firewall Manager applications list.
123 |
# File 'sig/client.rbs', line 123
def delete_apps_list: (
|
#delete_notification_channel(params = {}) ⇒ Struct
Deletes an Firewall Manager association with the IAM role and the Amazon Simple Notification Service (SNS) topic that is used to record Firewall Manager SNS logs.
129 |
# File 'sig/client.rbs', line 129
def delete_notification_channel: (
|
#delete_policy(params = {}) ⇒ Struct
Permanently deletes an Firewall Manager policy.
134 |
# File 'sig/client.rbs', line 134
def delete_policy: (
|
#delete_protocols_list(params = {}) ⇒ Struct
Permanently deletes an Firewall Manager protocols list.
141 |
# File 'sig/client.rbs', line 141
def delete_protocols_list: (
|
#delete_resource_set(params = {}) ⇒ Struct
Deletes the specified ResourceSet.
147 |
# File 'sig/client.rbs', line 147
def delete_resource_set: (
|
#disassociate_admin_account(params = {}) ⇒ Struct
Disassociates an Firewall Manager administrator account. To set a different account as an Firewall Manager administrator, submit a PutAdminAccount request. To set an account as a default administrator account, you must submit an AssociateAdminAccount request.
Disassociation of the default administrator account follows the first in, last out principle. If you are the default administrator, all Firewall Manager administrators within the organization must first disassociate their accounts before you can disassociate your account.
153 |
# File 'sig/client.rbs', line 153
def disassociate_admin_account: (
|
#disassociate_third_party_firewall(params = {}) ⇒ Types::DisassociateThirdPartyFirewallResponse
Disassociates a Firewall Manager policy administrator from a
third-party firewall tenant. When you call
DisassociateThirdPartyFirewall, the third-party firewall vendor
deletes all of the firewalls that are associated with the account.
162 |
# File 'sig/client.rbs', line 162
def disassociate_third_party_firewall: (
|
#get_admin_account(params = {}) ⇒ Types::GetAdminAccountResponse
Returns the Organizations account that is associated with Firewall Manager as the Firewall Manager default administrator.
173 |
# File 'sig/client.rbs', line 173
def get_admin_account: (
|
#get_admin_scope(params = {}) ⇒ Types::GetAdminScopeResponse
Returns information about the specified account's administrative scope. The administrative scope defines the resources that an Firewall Manager administrator can manage.
183 |
# File 'sig/client.rbs', line 183
def get_admin_scope: (
|
#get_apps_list(params = {}) ⇒ Types::GetAppsListResponse
Returns information about the specified Firewall Manager applications list.
194 |
# File 'sig/client.rbs', line 194
def get_apps_list: (
|
#get_compliance_detail(params = {}) ⇒ Types::GetComplianceDetailResponse
Returns detailed compliance information about the specified member account. Details include resources that are in and out of compliance with the specified policy.
The reasons for resources being considered compliant depend on the Firewall Manager policy type.
205 |
# File 'sig/client.rbs', line 205
def get_compliance_detail: (
|
#get_notification_channel(params = {}) ⇒ Types::GetNotificationChannelResponse
Information about the Amazon Simple Notification Service (SNS) topic that is used to record Firewall Manager SNS logs.
217 |
# File 'sig/client.rbs', line 217
def get_notification_channel: (
|
#get_policy(params = {}) ⇒ Types::GetPolicyResponse
Returns information about the specified Firewall Manager policy.
227 |
# File 'sig/client.rbs', line 227
def get_policy: (
|
#get_protection_status(params = {}) ⇒ Types::GetProtectionStatusResponse
If you created a Shield Advanced policy, returns policy-level attack summary information in the event of a potential DDoS attack. Other policy types are currently unsupported.
239 |
# File 'sig/client.rbs', line 239
def get_protection_status: (
|
#get_protocols_list(params = {}) ⇒ Types::GetProtocolsListResponse
Returns information about the specified Firewall Manager protocols list.
255 |
# File 'sig/client.rbs', line 255
def get_protocols_list: (
|
#get_resource_set(params = {}) ⇒ Types::GetResourceSetResponse
Gets information about a specific resource set.
267 |
# File 'sig/client.rbs', line 267
def get_resource_set: (
|
#get_third_party_firewall_association_status(params = {}) ⇒ Types::GetThirdPartyFirewallAssociationStatusResponse
The onboarding status of a Firewall Manager admin account to third-party firewall vendor tenant.
278 |
# File 'sig/client.rbs', line 278
def get_third_party_firewall_association_status: (
|
#get_violation_details(params = {}) ⇒ Types::GetViolationDetailsResponse
Retrieves violations for a resource based on the specified Firewall Manager policy and Amazon Web Services account.
288 |
# File 'sig/client.rbs', line 288
def get_violation_details: (
|
#list_admin_accounts_for_organization(params = {}) ⇒ Types::ListAdminAccountsForOrganizationResponse
Returns a AdminAccounts object that lists the Firewall Manager
administrators within the organization that are onboarded to Firewall
Manager by AssociateAdminAccount.
This operation can be called only from the organization's management account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
302 |
# File 'sig/client.rbs', line 302
def list_admin_accounts_for_organization: (
|
#list_admins_managing_account(params = {}) ⇒ Types::ListAdminsManagingAccountResponse
Lists the accounts that are managing the specified Organizations member account. This is useful for any member account so that they can view the accounts who are managing their account. This operation only returns the managing administrators that have the requested account within their AdminScope.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
314 |
# File 'sig/client.rbs', line 314
def list_admins_managing_account: (
|
#list_apps_lists(params = {}) ⇒ Types::ListAppsListsResponse
Returns an array of AppsListDataSummary objects.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
326 |
# File 'sig/client.rbs', line 326
def list_apps_lists: (
|
#list_compliance_status(params = {}) ⇒ Types::ListComplianceStatusResponse
Returns an array of PolicyComplianceStatus objects. Use
PolicyComplianceStatus to get a summary of which member accounts are
protected by the specified policy.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
339 |
# File 'sig/client.rbs', line 339
def list_compliance_status: (
|
#list_discovered_resources(params = {}) ⇒ Types::ListDiscoveredResourcesResponse
Returns an array of resources in the organization's accounts that are available to be associated with a resource set.
352 |
# File 'sig/client.rbs', line 352
def list_discovered_resources: (
|
#list_member_accounts(params = {}) ⇒ Types::ListMemberAccountsResponse
Returns a MemberAccounts object that lists the member accounts in
the administrator's Amazon Web Services organization.
Either an Firewall Manager administrator or the organization's management account can make this request.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
366 |
# File 'sig/client.rbs', line 366
def list_member_accounts: (
|
#list_policies(params = {}) ⇒ Types::ListPoliciesResponse
Returns an array of PolicySummary objects.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
378 |
# File 'sig/client.rbs', line 378
def list_policies: (
|
#list_protocols_lists(params = {}) ⇒ Types::ListProtocolsListsResponse
Returns an array of ProtocolsListDataSummary objects.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
390 |
# File 'sig/client.rbs', line 390
def list_protocols_lists: (
|
#list_resource_set_resources(params = {}) ⇒ Types::ListResourceSetResourcesResponse
Returns an array of resources that are currently associated to a resource set.
403 |
# File 'sig/client.rbs', line 403
def list_resource_set_resources: (
|
#list_resource_sets(params = {}) ⇒ Types::ListResourceSetsResponse
Returns an array of ResourceSetSummary objects.
416 |
# File 'sig/client.rbs', line 416
def list_resource_sets: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the list of tags for the specified Amazon Web Services resource.
427 |
# File 'sig/client.rbs', line 427
def list_tags_for_resource: (
|
#list_third_party_firewall_firewall_policies(params = {}) ⇒ Types::ListThirdPartyFirewallFirewallPoliciesResponse
Retrieves a list of all of the third-party firewall policies that are associated with the third-party firewall administrator's account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
438 |
# File 'sig/client.rbs', line 438
def list_third_party_firewall_firewall_policies: (
|
#put_admin_account(params = {}) ⇒ Struct
Creates or updates an Firewall Manager administrator account. The account must be a member of the organization that was onboarded to Firewall Manager by AssociateAdminAccount. Only the organization's management account can create an Firewall Manager administrator account. When you create an Firewall Manager administrator account, the service checks to see if the account is already a delegated administrator within Organizations. If the account isn't a delegated administrator, Firewall Manager calls Organizations to delegate the account within Organizations. For more information about administrator accounts within Organizations, see Managing the Amazon Web Services Accounts in Your Organization.
446 |
# File 'sig/client.rbs', line 446
def put_admin_account: (
|
#put_apps_list(params = {}) ⇒ Types::PutAppsListResponse
Creates an Firewall Manager applications list.
477 |
# File 'sig/client.rbs', line 477
def put_apps_list: (
|
#put_notification_channel(params = {}) ⇒ Struct
Designates the IAM role and Amazon Simple Notification Service (SNS) topic that Firewall Manager uses to record SNS logs.
To perform this action outside of the console, you must first
configure the SNS topic's access policy to allow the SnsRoleName to
publish SNS logs. If the SnsRoleName provided is a role other than
the AWSServiceRoleForFMS service-linked role, this role must have a
trust relationship configured to allow the Firewall Manager service
principal fms.amazonaws.com to assume this role. For information
about configuring an SNS access policy, see Service roles for
Firewall Manager in the Firewall Manager Developer Guide.
509 |
# File 'sig/client.rbs', line 509
def put_notification_channel: (
|
#put_policy(params = {}) ⇒ Types::PutPolicyResponse
Creates an Firewall Manager policy.
A Firewall Manager policy is specific to the individual policy type. If you want to enforce multiple policy types across accounts, you can create multiple policies. You can create more than one policy for each type.
If you add a new account to an organization that you created with Organizations, Firewall Manager automatically applies the policy to the resources in that account that are within scope of the policy.
Firewall Manager provides the following types of policies:
-
WAF policy - This policy applies WAF web ACL protections to specified accounts and resources.
-
Shield Advanced policy - This policy applies Shield Advanced protection to specified accounts and resources.
-
Security Groups policy - This type of policy gives you control over security groups that are in use throughout your organization in Organizations and lets you enforce a baseline set of rules across your organization.
-
Network ACL policy - This type of policy gives you control over the network ACLs that are in use throughout your organization in Organizations and lets you enforce a baseline set of first and last network ACL rules across your organization.
-
Network Firewall policy - This policy applies Network Firewall protection to your organization's VPCs.
-
DNS Firewall policy - This policy applies Amazon Route 53 Resolver DNS Firewall protections to your organization's VPCs.
-
Third-party firewall policy - This policy applies third-party firewall protections. Third-party firewalls are available by subscription through the Amazon Web Services Marketplace console at Amazon Web Services Marketplace.
-
Palo Alto Networks Cloud NGFW policy - This policy applies Palo Alto Networks Cloud Next Generation Firewall (NGFW) protections and Palo Alto Networks Cloud NGFW rulestacks to your organization's VPCs.
-
Fortigate CNF policy - This policy applies Fortigate Cloud Native Firewall (CNF) protections. Fortigate CNF is a cloud-centered solution that blocks Zero-Day threats and secures cloud infrastructures with industry-leading advanced threat prevention, smart web application firewalls (WAF), and API protection.
521 |
# File 'sig/client.rbs', line 521
def put_policy: (
|
#put_protocols_list(params = {}) ⇒ Types::PutProtocolsListResponse
Creates an Firewall Manager protocols list.
583 |
# File 'sig/client.rbs', line 583
def put_protocols_list: (
|
#put_resource_set(params = {}) ⇒ Types::PutResourceSetResponse
Creates the resource set.
An Firewall Manager resource set defines the resources to import into an Firewall Manager policy from another Amazon Web Services service.
608 |
# File 'sig/client.rbs', line 608
def put_resource_set: (
|
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to an Amazon Web Services resource.
631 |
# File 'sig/client.rbs', line 631
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from an Amazon Web Services resource.
646 |
# File 'sig/client.rbs', line 646
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2993 2994 2995 |
# File 'lib/aws-sdk-fms/client.rb', line 2993 def waiter_names [] end |