Class: Aws::FMS::Types::GetViolationDetailsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::FMS::Types::GetViolationDetailsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-fms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#member_account ⇒ String
The Amazon Web Services account ID that you want the details for.
-
#policy_id ⇒ String
The ID of the Firewall Manager policy that you want the details for.
-
#resource_id ⇒ String
The ID of the resource that has violations.
-
#resource_type ⇒ String
The resource type.
Instance Attribute Details
#member_account ⇒ String
The Amazon Web Services account ID that you want the details for.
1853 1854 1855 1856 1857 1858 1859 1860 |
# File 'lib/aws-sdk-fms/types.rb', line 1853 class GetViolationDetailsRequest < Struct.new( :policy_id, :member_account, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#policy_id ⇒ String
The ID of the Firewall Manager policy that you want the details for. You can get violation details for the following policy types:
-
WAF
-
DNS Firewall
-
Imported Network Firewall
-
Network Firewall
-
Security group content audit
-
Network ACL
-
Third-party firewall
1853 1854 1855 1856 1857 1858 1859 1860 |
# File 'lib/aws-sdk-fms/types.rb', line 1853 class GetViolationDetailsRequest < Struct.new( :policy_id, :member_account, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The ID of the resource that has violations.
1853 1854 1855 1856 1857 1858 1859 1860 |
# File 'lib/aws-sdk-fms/types.rb', line 1853 class GetViolationDetailsRequest < Struct.new( :policy_id, :member_account, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The resource type. This is in the format shown in the Amazon Web
Services Resource Types Reference. Supported resource types are:
AWS::WAFv2::WebACL, AWS::EC2::Instance,
AWS::EC2::NetworkInterface, AWS::EC2::SecurityGroup,
AWS::NetworkFirewall::FirewallPolicy, and AWS::EC2::Subnet.
1853 1854 1855 1856 1857 1858 1859 1860 |
# File 'lib/aws-sdk-fms/types.rb', line 1853 class GetViolationDetailsRequest < Struct.new( :policy_id, :member_account, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |