Method: Aws::FMS::Types::GetProtectionStatusRequest#start_time
- Defined in:
- lib/aws-sdk-fms/types.rb
#start_time ⇒ Time
The start of the time period to query for the attacks. This is a timestamp type. The request syntax listing indicates a number type because the default used by Firewall Manager is Unix time in seconds. However, any valid timestamp format is allowed.
1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 |
# File 'lib/aws-sdk-fms/types.rb', line 1624 class GetProtectionStatusRequest < Struct.new( :policy_id, :member_account_id, :start_time, :end_time, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |