Method: Aws::FMS::Types::ResourceSet#id
- Defined in:
- lib/aws-sdk-fms/types.rb
#id ⇒ String
A unique identifier for the resource set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 |
# File 'lib/aws-sdk-fms/types.rb', line 4377 class ResourceSet < Struct.new( :id, :name, :description, :update_token, :resource_type_list, :last_update_time, :resource_set_status) SENSITIVE = [] include Aws::Structure end |